/*
 * XdccDownloader - MotdReceived.java - Copyright © 2013 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.irc.event;

import net.pterodactylus.irc.Connection;

/**
 * Notifies a listener that a server’s MOTD (message of the day) was received.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class MotdReceived extends AbstractConnectionEvent {

	/** The MOTD of the server. */
	private final String motd;

	/**
	 * Creates a new MOTD received event.
	 *
	 * @param connection
	 * 		The connection the event occured on
	 * @param motd
	 * 		The MOTD of the server
	 */
	public MotdReceived(Connection connection, String motd) {
		super(connection);
		this.motd = motd;
	}

	//
	// ACCESSORS
	//

	/**
	 * Returns the MOTD of the server.
	 *
	 * @return The MOTD of the server
	 */
	public String motd() {
		return motd;
	}

}
