/*
 * XdccDownloader - NicknameInUseReceived.java - Copyright © 2013 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.irc.event;

import net.pterodactylus.irc.Connection;
import net.pterodactylus.irc.Reply;

/**
 * Notifies a listener that a nickname is already in use.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class NicknameInUseReceived extends AbstractReplyEvent {

	/** The nickname that is already in use. */
	private final String nickname;

	/** The message from the server. */
	private final String message;

	/**
	 * Creates a new nickname in use event.
	 *
	 * @param connection
	 * 		The connection the event occured on
	 * @param reply
	 * 		The reply that caused the event
	 */
	public NicknameInUseReceived(Connection connection, Reply reply) {
		super(connection, reply);
		nickname = reply.parameters().get(0);
		message = reply.parameters().get(1);
	}

	//
	// ACCESSORS
	//

	/**
	 * Returns the nickname that is already in use.
	 *
	 * @return The nickname that is already in use
	 */
	public String nickname() {
		return nickname;
	}

	/**
	 * Returns the message from the IRC server.
	 *
	 * @return The message from the IRC server
	 */
	public String message() {
		return message;
	}

}
